/*************************************************************
 *
 *  MathJax/localization/diq/HTML-CSS.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("diq","HTML-CSS",{
        version: "2.7.3",
        isLoaded: true,
        strings: {
          LoadWebFont: "Web font %1 bar beno",
          CantLoadWebFont: "Font\u00EA web\u00EA %1'i bar n\u00EAb\u0131"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/diq/HTML-CSS.js");
